==> dotclear-1.2-rc.zip: dotclear/l10n/fr-utf8/messages.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['No such user ID or invalid user ID'] = 'Pas d\'identifiant ou identifiant invalide';
$GLOBALS['__l10n']['Invalid user level'] = 'Niveau d\'utilisateur invalide';
$GLOBALS['__l10n']['User password missing'] = 'Pas de mot de passe';
$GLOBALS['__l10n']['User name missing'] = 'Pas de nom d\'utilisateur';
$GLOBALS['__l10n']['Invalid email address'] = 'Adresse email invalide';
$GLOBALS['__l10n']['Invalid publication format'] = 'Format de publication invalide';
$GLOBALS['__l10n']['Invalid edit size'] = 'Taille d\'édition invalide';
$GLOBALS['__l10n']['Category does not exist'] = 'Catégorie inexistante';
$GLOBALS['__l10n']['This user has entries'] = 'L\'utilisateur a des billets';
$GLOBALS['__l10n']['Empty category title'] = 'Le libellé de la catégorie est vide';
$GLOBALS['__l10n']['No category ID'] = 'Pas d\'identifiant de catégorie';
$GLOBALS['__l10n']['This category is not empty'] = 'La catégorie n\'est pas vide';
$GLOBALS['__l10n']['Empty or invalid URLed title'] = 'Le titre URL de la catégorie est vide ou invalide';
$GLOBALS['__l10n']['Empty entry title'] = 'Titre du billet vide';
$GLOBALS['__l10n']['Empty entry content'] = 'Contenu du billet vide';
$GLOBALS['__l10n']['No entry ID'] = 'Pas d\'identifiant de billet';
$GLOBALS['__l10n']['Empty comment author'] = 'Auteur du commentaire vide';
$GLOBALS['__l10n']['Empty comment content'] = 'Contenu du commentaire vide';
$GLOBALS['__l10n']['Entry does not exists'] = 'Billet inexistant';
$GLOBALS['__l10n']['Source is not a ping URL'] = 'La source n\'est pas une URL de ping';
$GLOBALS['__l10n']['Trackback error'] = 'Erreur de trackback';
$GLOBALS['__l10n']['No entry.'] = 'Aucun billet.';
$GLOBALS['__l10n']['Comment for entry %s'] = 'Commentaire pour le billet %s';
$GLOBALS['__l10n']['By: %s'] = 'Par : %s';
$GLOBALS['__l10n']['Website: %s'] = 'Site Web : %s';
$GLOBALS['__l10n']['Search of %s doesn\'t give any result.'] = 'La recherche de %s ne donne aucun résultat.';
$GLOBALS['__l10n']['Strong emphasis'] = 'Forte emphase';
$GLOBALS['__l10n']['Emphasis'] = 'Emphase';
$GLOBALS['__l10n']['Inserted'] = 'Inséré';
$GLOBALS['__l10n']['Deleted'] = 'Supprimé';
$GLOBALS['__l10n']['Inline quote'] = 'Citation en ligne';
$GLOBALS['__l10n']['Code'] = 'Code';
$GLOBALS['__l10n']['Line break'] = 'Saut de ligne';
$GLOBALS['__l10n']['Blockquote'] = 'Bloc de citation';
$GLOBALS['__l10n']['Preformated text'] = 'Texte préformaté';
$GLOBALS['__l10n']['Unordered list'] = 'Liste non ordonnée';
$GLOBALS['__l10n']['Ordered list'] = 'Liste ordonnée';
$GLOBALS['__l10n']['URL?'] = 'URL ?';
$GLOBALS['__l10n']['Language?'] = 'Langue ?';
$GLOBALS['__l10n']['Link'] = 'Lien';
$GLOBALS['__l10n']['External image'] = 'Image externe';
$GLOBALS['__l10n']['Internal image'] = 'Image interne';
?>

==> dotclear-1.2.6.zip: dotclear/l10n/fr-utf8/messages.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['No such user ID or invalid user ID'] = 'Pas d\'identifiant ou identifiant invalide';
$GLOBALS['__l10n']['Invalid user level'] = 'Niveau d\'utilisateur invalide';
$GLOBALS['__l10n']['User password missing'] = 'Pas de mot de passe';
$GLOBALS['__l10n']['User name missing'] = 'Pas de nom d\'utilisateur';
$GLOBALS['__l10n']['Invalid email address'] = 'Adresse email invalide';
$GLOBALS['__l10n']['Invalid publication format'] = 'Format de publication invalide';
$GLOBALS['__l10n']['Invalid edit size'] = 'Taille d\'édition invalide';
$GLOBALS['__l10n']['Category does not exist'] = 'Catégorie inexistante';
$GLOBALS['__l10n']['This user has entries'] = 'L\'utilisateur a des billets';
$GLOBALS['__l10n']['Empty category title'] = 'Le libellé de la catégorie est vide';
$GLOBALS['__l10n']['No category ID'] = 'Pas d\'identifiant de catégorie';
$GLOBALS['__l10n']['This category is not empty'] = 'La catégorie n\'est pas vide';
$GLOBALS['__l10n']['Empty or invalid URLed title'] = 'Le titre URL de la catégorie est vide ou invalide';
$GLOBALS['__l10n']['Empty entry title'] = 'Titre du billet vide';
$GLOBALS['__l10n']['Empty entry content'] = 'Contenu du billet vide';
$GLOBALS['__l10n']['No entry ID'] = 'Pas d\'identifiant de billet';
$GLOBALS['__l10n']['Empty comment author'] = 'Auteur du commentaire vide';
$GLOBALS['__l10n']['Empty comment content'] = 'Contenu du commentaire vide';
$GLOBALS['__l10n']['Entry does not exists'] = 'Billet inexistant';
$GLOBALS['__l10n']['Source is not a ping URL'] = 'La source n\'est pas une URL de ping';
$GLOBALS['__l10n']['Trackback error'] = 'Erreur de trackback';
$GLOBALS['__l10n']['No entry.'] = 'Aucun billet.';
$GLOBALS['__l10n']['Comment for entry %s'] = 'Commentaire pour le billet %s';
$GLOBALS['__l10n']['By: %s'] = 'Par : %s';
$GLOBALS['__l10n']['Website: %s'] = 'Site Web : %s';
$GLOBALS['__l10n']['Search of %s doesn\'t give any result.'] = 'La recherche de %s ne donne aucun résultat.';
$GLOBALS['__l10n']['Your comment has been sent successfully. It will be online soon.'] = 'Votre commentaire a été envoyé. Il sera en ligne bientôt.';
$GLOBALS['__l10n']['Strong emphasis'] = 'Forte emphase';
$GLOBALS['__l10n']['Emphasis'] = 'Emphase';
$GLOBALS['__l10n']['Inserted'] = 'Inséré';
$GLOBALS['__l10n']['Deleted'] = 'Supprimé';
$GLOBALS['__l10n']['Inline quote'] = 'Citation en ligne';
$GLOBALS['__l10n']['Code'] = 'Code';
$GLOBALS['__l10n']['Line break'] = 'Saut de ligne';
$GLOBALS['__l10n']['Blockquote'] = 'Bloc de citation';
$GLOBALS['__l10n']['Preformated text'] = 'Texte préformaté';
$GLOBALS['__l10n']['Unordered list'] = 'Liste non ordonnée';
$GLOBALS['__l10n']['Ordered list'] = 'Liste ordonnée';
$GLOBALS['__l10n']['URL?'] = 'URL ?';
$GLOBALS['__l10n']['Language?'] = 'Langue ?';
$GLOBALS['__l10n']['Link'] = 'Lien';
$GLOBALS['__l10n']['External image'] = 'Image externe';
$GLOBALS['__l10n']['Internal image'] = 'Image interne';
?>
